def getNativeInfo(vmanage, deviceId):
    """
    Get device system native settings from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/csp/system/native?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getProcessList(vmanage, deviceId):
    """
    Get device system process list from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/csp/system/processlist?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSetting(vmanage, deviceId):
    """
    Get device system settings from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/csp/system/settings?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStatus(vmanage, deviceId):
    """
    Get device system status from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/csp/system/status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getInfoList(vmanage, deviceId):
    """
    Get device information list
    
    Parameters:
    deviceId	 (array):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/system/info?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStats(vmanage, deviceId):
    """
    Get device system stats list (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/system/statistics?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStatusList(vmanage, deviceId):
    """
    Get device system status list (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/system/status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSyncedStatusList(vmanage, deviceId):
    """
    Get device system stats list synchronously
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/system/synced/status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



from py_viptela.api.mdp import config
from py_viptela.api.mdp import devicesharing
from py_viptela.api.mdp import internalpolicy
from py_viptela.api.mdp import offboard
from py_viptela.api.mdp import onboard
from py_viptela.api.mdp import policy


def cancelPending(vmanage, processId):
    """
    Bulk cancel task status
    
    Parameters:
    processId	 (string):	Process Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/status/cancel/{processId}"
    response = vmanage.apiCall("POST", endpoint)
    return response

def cleanStatus(vmanage, cleanStatus):
    """
    Delete task and status vertex
    
    Parameters:
    cleanStatus	 (boolean):	Clear status flag
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/status/clean?cleanStatus={cleanStatus}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def deleteStatus(vmanage, processId):
    """
    Delete status of action
    
    Parameters:
    processId	 (string):	Process Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/status/clear?processId={processId}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response

def findRunning(vmanage):
    """
    Find running tasks
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/status/tasks"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getActiveCount(vmanage):
    """
    Get active task count
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/status/tasks/activeCount"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getCleanStatus(vmanage, processId):
    """
    Delete task and status vertex
    
    Parameters:
    processId	 (string):	Process Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/status/tasks/clean?processId={processId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def findStatus(vmanage, actionName):
    """
    Find status of action
    
    Parameters:
    actionName	 (string):	Action name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/status/{actionName}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getBanner(vmanage):
    """
    Retrieve banner
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/settings/banner"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getSessionTimout(vmanage):
    """
    Get client session timeout
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/settings/clientSessionTimeout"
    response = vmanage.apiCall("GET", endpoint)
    return response

def createAnalyticsDataFile(vmanage):
    """
    Create analytics data file
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/settings/configuration/analytics/dca"
    response = vmanage.apiCall("POST", endpoint)
    return response

def getCertConfig(vmanage, settingType):
    """
    Retrieve certificate configuration value by settingType
    
    Parameters:
    settingType	 (string):	Setting type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/settings/configuration/certificate/{settingType}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def editCertConfig(vmanage, certConfig, settingType):
    """
    Update certificate configuration
    
    Parameters:
    certConfig:	Certificate config
	settingType	 (string):	Setting type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/settings/configuration/certificate/{settingType}"
    response = vmanage.apiCall("PUT", endpoint, certConfig)
    return response

def newCertConfig(vmanage, certConfig, settingType):
    """
    Add new certificate configuration
    
    Parameters:
    certConfig:	Certificate config
	settingType	 (string):	Setting type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/settings/configuration/certificate/{settingType}"
    response = vmanage.apiCall("POST", endpoint, certConfig)
    return response

def getGoogleMapKey(vmanage):
    """
    Retrieve Google map key
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/settings/configuration/googleMapKey"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getMaintenanceWindow(vmanage):
    """
    Retrieve maintenance window
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/settings/configuration/maintenanceWindow"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getConfigBySettingType(vmanage, settingType):
    """
    Retrieve configuration value by settingType
    
    Parameters:
    settingType	 (string):	Setting type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/settings/configuration/{settingType}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def editConfig(vmanage, configSetting, settingType):
    """
    Update configuration setting
    
    Parameters:
    configSetting:	Configuration setting
	settingType	 (string):	Setting type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/settings/configuration/{settingType}"
    response = vmanage.apiCall("PUT", endpoint, configSetting)
    return response

def newConfig(vmanage, configSetting, settingType):
    """
    Add new configuration
    
    Parameters:
    configSetting:	Configuration setting
	settingType	 (string):	Setting type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/settings/configuration/{settingType}"
    response = vmanage.apiCall("POST", endpoint, configSetting)
    return response



def getClients(vmanage, deviceId):
    """
    Get wireless clients from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/wireless/client?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getRadios(vmanage, deviceId):
    """
    Get wireless Radios from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/wireless/radio?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSsid(vmanage, deviceId):
    """
    Get wireless SSID from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/wireless/ssid?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getStatDataRawData(vmanage, query):
    """
    Get stats raw data
    
    Parameters:
    query	 (string):	Query string
    
    Returns
    response    (dict)
    
    
    """
    query_string = vmanage.builder.generateQuery(query)
    endpoint = f"dataservice/device/history?query={query_string}"
    response     = vmanage.apiCall("GET", endpoint)
    return response

def getStatsRawData(vmanage, query):
    """
    Get stats raw data
    
    Parameters:
    query:	Stats query string
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/history"
    response = vmanage.apiCall("POST", endpoint, query)
    return response

def getAggregationDataByQuery(vmanage, query):
    """
    Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
    
    Parameters:
    query	 (string):	Query filter
    
    Returns
    response    (dict)
    
    
    """
    query_string = vmanage.builder.generateQuery(query)
    endpoint = f"dataservice/device/history/aggregation?query={query_string}"
    response     = vmanage.apiCall("GET", endpoint)
    return response

def getPostAggregationDataByQuery(vmanage, query):
    """
    Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
    
    Parameters:
    query:	Stats query string
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/history/aggregation"
    response = vmanage.apiCall("POST", endpoint, query)
    return response

def getPostAggregationAppDataByQuery(vmanage, query):
    """
    Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
    
    Parameters:
    query:	Stats query string
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/history/app-agg/aggregation"
    response = vmanage.apiCall("POST", endpoint, query)
    return response

def getLastThousandConfigList(vmanage, deviceId, query):
    """
    Get device config history
    
    Parameters:
    deviceId	 (string):	Device Id
	query	 (string):	Query filter
    
    Returns
    response    (dict)
    
    
    """
    query_string = vmanage.builder.generateQuery(query)
    endpoint = f"dataservice/device/history/config?deviceId={deviceId}&query={query_string}"
    response     = vmanage.apiCall("GET", endpoint)
    return response

def getConfigDiff(vmanage, config_id1, config_id2):
    """
    Get diff of two configs
    
    Parameters:
    config_id1	 (string):	Config Id one
	config_id2	 (string):	Config Id two
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/history/config/diff/list?config_id1={config_id1}&config_id2={config_id2}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getDeviceConfig(vmanage, config_id):
    """
    Get device config
    
    Parameters:
    config_id	 (string):	Config Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/history/config/{config_id}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getStatDataRawDataAsCSV(vmanage, query):
    """
    Get raw data with optional query as CSV
    
    Parameters:
    query	 (string):	Query string
    
    Returns
    response    (dict)
    
    
    """
    query_string = vmanage.builder.generateQuery(query)
    endpoint = f"dataservice/device/history/csv?query={query_string}"
    response     = vmanage.apiCall("GET", endpoint)
    return response

def getCount(vmanage, query):
    """
    Get response count of a query
    
    Parameters:
    query	 (string):	Query
    
    Returns
    response    (dict)
    
    
    """
    query_string = vmanage.builder.generateQuery(query)
    endpoint = f"dataservice/device/history/doccount?query={query_string}"
    response     = vmanage.apiCall("GET", endpoint)
    return response

def getCountPost(vmanage, query):
    """
    Get response count of a query
    
    Parameters:
    query:	Query
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/history/doccount"
    response = vmanage.apiCall("POST", endpoint, query)
    return response

def getStatDataFields(vmanage):
    """
    Get fields and type
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/history/fields"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getStatBulkRawData(vmanage, query, scrollId, count):
    """
    Get stats raw data
    
    Parameters:
    query	 (string):	Query string
	scrollId	 (string):	ES scroll Id
	count	 (string):	Result size
    
    Returns
    response    (dict)
    
    
    """
    query_string = vmanage.builder.generateQuery(query)
    endpoint = f"dataservice/device/history/page?query={query_string}&scrollId={scrollId}&count={count}"
    response     = vmanage.apiCall("GET", endpoint)
    return response

def getPostStatBulkRawData(vmanage, query, scrollId, count):
    """
    Get stats raw data
    
    Parameters:
    query:	Stats query string
	scrollId	 (string):	ES scroll Id
	count	 (string):	Result size
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/history/page?scrollId={scrollId}&count={count}"
    response = vmanage.apiCall("POST", endpoint, query)
    return response

def getStatQueryFields(vmanage):
    """
    Get query fields
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/history/query/fields"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getWLANClients(vmanage, deviceId):
    """
    Get WLAN client from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/wlan/clients?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getWLANInterfaces(vmanage, deviceId):
    """
    Get WLAN interface from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/wlan/interfaces?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getWLANRadios(vmanage, deviceId):
    """
    Get WLAN Radios from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/wlan/radios?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getWLANRadius(vmanage, deviceId):
    """
    Get WLAN RADIUS authentication from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/wlan/radius?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def pushMasterBootstrap(vmanage, bootstrapTemplate):
    """
    Attach bootstrap template to device
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    bootstrapTemplate:	Device template
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/config/attachBootStrap"
    response = vmanage.apiCall("POST", endpoint, bootstrapTemplate)
    return response

def pushCLITemplate(vmanage, devicetemplate):
    """
    Attach CLI device template
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    devicetemplate:	Device template
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/config/attachcli"
    response = vmanage.apiCall("POST", endpoint, devicetemplate)
    return response

def editCloudxConfig(vmanage, cloudxconfig):
    """
    Edit already enabled gateways, clients, dias
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    cloudxconfig:	CloudX config
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/config/attachcloudx"
    response = vmanage.apiCall("PUT", endpoint, cloudxconfig)
    return response

def pushCloudxConfig(vmanage, cloudxconfig):
    """
    Enable gateways, clients, dias
    
    Parameters:
    cloudxconfig:	CloudX config
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/config/attachcloudx"
    response = vmanage.apiCall("POST", endpoint, cloudxconfig)
    return response

def getAttachedDeviceList(vmanage, masterTemplateId):
    """
    Get attached device list by master template Id
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    masterTemplateId	 (string):	Template Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/config/attached/{masterTemplateId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getAttachedConfigToDevice(vmanage, deviceId):
    """
    Get attached config to device
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    deviceId	 (string):	Device Model ID
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/config/attachedconfig?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def pushMasterTemplate(vmanage, devicetemplate):
    """
    Attach feature device template
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    devicetemplate:	Device template
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/config/attachfeature"
    response = vmanage.apiCall("POST", endpoint, devicetemplate)
    return response

def attachDeviceTemplate(vmanage, devicetemplate):
    """
    Attach device template
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    devicetemplate:	Device template
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/config/attachment"
    response = vmanage.apiCall("POST", endpoint, devicetemplate)
    return response

def getDeviceListByMasterTemplateId(vmanage, masterTemplateId):
    """
    Get possible device list by master template Id
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    masterTemplateId	 (string):	Template Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/config/available/{masterTemplateId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getDeviceConfigurationPreview(vmanage, devicetemplate):
    """
    Get device configuration
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    devicetemplate:	Device template
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/config/config"
    response = vmanage.apiCall("POST", endpoint, devicetemplate)
    return response

def detachDeviceTemplate(vmanage, devicetemplate):
    """
    Detach device template
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    devicetemplate:	Device template
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/config/detach"
    response = vmanage.apiCall("POST", endpoint, devicetemplate)
    return response

def detachSites(vmanage, cloudxconfig):
    """
    Disable enabled gateways, clients, dias
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    cloudxconfig:	CloudX config
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/config/detachcloudx"
    response = vmanage.apiCall("POST", endpoint, cloudxconfig)
    return response

def getDevicesWithDuplicateIP(vmanage, devicelist):
    """
    Detects duplicate system IP from a list of devices
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    devicelist:	Device list
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/config/duplicateip"
    response = vmanage.apiCall("POST", endpoint, devicelist)
    return response

def createInputWithoutDevice(vmanage, devicetemplate):
    """
    Export the device template to CSV format for given template id
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    devicetemplate:	Device template
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/config/exportcsv"
    response = vmanage.apiCall("POST", endpoint, devicetemplate)
    return response

def createDeviceInput(vmanage, templatedeviceinput):
    """
    Create device input
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    templatedeviceinput:	Template device input
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/config/input"
    response = vmanage.apiCall("POST", endpoint, templatedeviceinput)
    return response

def processInputCommaSepFile(vmanage, devicetemplate):
    """
    Process input comma separated file
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    devicetemplate:	Device template
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/config/process/input/file"
    response = vmanage.apiCall("POST", endpoint, devicetemplate)
    return response

def getQuickConnectVariables(vmanage, devicelist):
    """
    Get connection variables to be configured
    
    Parameters:
    devicelist:	Device List
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/config/quickconnectvariable"
    response = vmanage.apiCall("POST", endpoint, devicelist)
    return response

def checkVbond(vmanage):
    """
    Check if vBond is configured
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/config/vbond"
    response = vmanage.apiCall("GET", endpoint)
    return response

def validateTemplate(vmanage, payload):
    """
    Validate full template"
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    payload:	Description
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/config/verify"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response



def getDreAutoBypassStats(vmanage, ip, port, deviceId):
    """
    Get DRE auto-bypass statistics
    
    Parameters:
    ip	            (string):	Server IP
	port	        (number):	Port
	deviceId	    (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/dre/auto-bypass-stats?appqoe-dre-auto-bypass-server-ip={ip}&appqoe-dre-auto-bypass-port={port}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getDreStats(vmanage, deviceId):
    """
    Get DRE statistics
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/dre/dre-stats?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getDreStatus(vmanage, deviceId):
    """
    Get DRE status
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/dre/dre-status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getDrePeerStats(vmanage, ip, peerNo, deviceId):
    """
    Get DRE peer statistics
    
    Parameters:
    ip	 (string):	System IP
	peerNo	 (number):	Peer Number
	deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/dre/peer-stats?appqoe-dre-stats-peer-system-ip={ip}&appqoe-dre-stats-peer-peer-no={peerNo}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def get(vmanage, uuid):
    """
    Get reverse proxy IP/Port mappings for controller
    
    Parameters:
    uuid	 (string):	Device uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/system/reverseproxy/{uuid}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def create(vmanage, mapping, uuid):
    """
    Create reverse proxy IP/Port mappings for controller
    
    Parameters:
    mapping:	Device reverse proxy mappings
	uuid	 (string):	Device uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/system/reverseproxy/{uuid}"
    response = vmanage.apiCall("POST", endpoint, mapping)
    return response



def getFeatureTemplateList(vmanage, summary, offset, limit):
    """
    Get feature template list
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    summary	 (boolean):	Flag to include template definition
	offset	 (integer):	Pagination offset
	limit	 (integer):	Pagination limit on templateId
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/feature?summary={summary}&offset={offset}&limit={limit}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def createFeatureTemplate(vmanage, featuretemplate):
    """
    Create feature template
    
    Parameters:
    featuretemplate:	Feature template
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/feature"
    response = vmanage.apiCall("POST", endpoint, featuretemplate)
    return response

def cloneTemplate(vmanage, id, name, desc):
    """
    Clone a feature template
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    id	 (string):	Template Id to clone from
	name	 (string):	Name for the cloned template
	desc	 (string):	Description for the cloned template
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/feature/clone?id={id}&name={name}&desc={desc}"
    response = vmanage.apiCall("POST", endpoint)
    return response

def getNetworkInterface(vmanage, deviceModel):
    """
    Get default network interface
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    deviceModel	 (string):	Device model
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/feature/default/networkinterface?deviceModel={deviceModel}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getDefaultNetworks(vmanage, deviceModel):
    """
    Get default networks
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    deviceModel	 (string):	Device model
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/feature/default/networks?deviceModel={deviceModel}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getTemplateDefinition(vmanage, templateId):
    """
    Get the configured template definition for given template Id
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    templateId	 (string):	Template Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/feature/definition/{templateId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getDeviceTemplatesAttachedToFeature(vmanage, templateId):
    """
    Get all device templates for this feature template
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    templateId	 (string):	Feature template Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/feature/devicetemplates/{templateId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def listLITemplate(vmanage):
    """
    Get LI feature template
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/feature/li"
    response = vmanage.apiCall("GET", endpoint)
    return response

def createLITemplate(vmanage, litemplate):
    """
    Create LI feature template
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    litemplate:	LI template
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/feature/li"
    response = vmanage.apiCall("POST", endpoint, litemplate)
    return response

def editLITemplate(vmanage, litemplate, templateId):
    """
    Update LI feature template
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    litemplate:	LI template
	templateId	 (string):	Template Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/feature/li/{templateId}"
    response = vmanage.apiCall("PUT", endpoint, litemplate)
    return response

def getMasterTemplateDefinition(vmanage, type_name):
    """
    Generate template type definition by device type
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    type_name	 (string):	Device type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/feature/master/{type_name}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getTemplateForMigration(vmanage):
    """
    Generate a list of templates which require migration
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/feature/migration"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getGeneralTemplate(vmanage, templateId):
    """
    Get template object definition for given template Id
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    templateId	 (string):	Template Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/feature/object/{templateId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def changeTemplateResourceGroup(vmanage, templateId, resourceGroupName):
    """
    Change template resource group
    
    Parameters:
    templateId	 (string):	Template Id
	resourceGroupName	 (string):	Resrouce group name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/feature/resource-group/{resourceGroupName}/{templateId}"
    response = vmanage.apiCall("POST", endpoint)
    return response

def getTemplateTypes(vmanage, type):
    """
    Generate template types
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    type	 (string):	Device type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/feature/types?type={type}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getTemplateTypeDefinition(vmanage, type_name, version):
    """
    Generate template type definition
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    type_name	 (string):	Device type
	version	 (string):	Version
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/feature/types/definition/{type_name}/{version}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getTemplateByDeviceType(vmanage, deviceType):
    """
    Generate template based on device
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    deviceType	 (string):	Device type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/feature/{deviceType}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def editFeatureTemplate(vmanage, template, templateId):
    """
    Update feature template
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    template:	Template
	templateId	 (string):	Template Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/feature/{templateId}"
    response = vmanage.apiCall("PUT", endpoint, template)
    return response

def deleteGeneralTemplate(vmanage, templateId):
    """
    Delete feature template
    
    Parameters:
    templateId	 (string):	Template Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/feature/{templateId}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response

def getEncryptedString(vmanage, type6encryption):
    """
    Get Type 6 Encryptedd String for a given value
    
    Parameters:
    type6encryption:	Type6 Encryption
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/security/encryptText/encrypt"
    response = vmanage.apiCall("POST", endpoint, type6encryption)
    return response



from py_viptela.api.config.builder.policy import appprobeclass
from py_viptela.api.config.builder.policy import cloudapplication
from py_viptela.api.config.builder.policy import customapplication
from py_viptela.api.config.builder.policy import geolocation
from py_viptela.api.config.builder.policy import mirror
from py_viptela.api.config.builder.policy import policerclass
from py_viptela.api.config.builder.policy import sig
from py_viptela.api.config.builder.policy import slaclass
from py_viptela.api.config.builder.policy import threatgridapi
from py_viptela.api.config.builder.policy import umbrelladata
from py_viptela.api.config.builder.policy import urlblacklist
from py_viptela.api.config.builder.policy import urlwhitelist


def getAccessTokenforDevice(vmanage):
    """
    getAccessTokenforDevice Description
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/cloudservices/accesstoken"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getAzureToken(vmanage, bodyParameter):
    """
    Get Azure token
    
    Parameters:
    bodyParameter:	Description
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/cloudservices/authtoken"
    response = vmanage.apiCall("POST", endpoint, bodyParameter)
    return response
def connect(vmanage):
    """
    Telemetry Opt In
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/cloudservices/connect"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getCloudCreds(vmanage):
    """
    Get cloud service credentials
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/cloudservices/credentials"
    response = vmanage.apiCall("GET", endpoint)
    return response
def addCloudCreds(vmanage, bodyParameter):
    """
    Get cloud service settings
    
    Parameters:
    bodyParameter:	Description
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/cloudservices/credentials"
    response = vmanage.apiCall("POST", endpoint, bodyParameter)
    return response
def getDeviceCode(vmanage):
    """
    Get Azure device code
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/cloudservices/devicecode"
    response = vmanage.apiCall("POST", endpoint)
    return response
def isStaging(vmanage):
    """
    Check if testbed or production
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/cloudservices/staging"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getTelemetryState(vmanage):
    """
    Get Telemetry state
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/cloudservices/telemetry"
    response = vmanage.apiCall("GET", endpoint)
    return response
def optIn(vmanage, bodyParameter):
    """
    Telemetry Opt In
    
    Parameters:
    bodyParameter:	Description
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/cloudservices/telemetry/optin"
    response = vmanage.apiCall("PUT", endpoint, bodyParameter)
    return response
def optOut(vmanage, bodyParameter):
    """
    Telemetry Opt Out
    
    Parameters:
    bodyParameter:	Description
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/cloudservices/telemetry/optout"
    response = vmanage.apiCall("DELETE", endpoint, bodyParameter)
    return response
def getCloudSettings(vmanage):
    """
    Get cloud service settings
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/dca/cloudservices"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getOTP(vmanage):
    """
    Get cloud service OTP value
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/dca/cloudservices/otp"
    response = vmanage.apiCall("GET", endpoint)
    return response
def updatetOTP(vmanage, cloudserviceotpvalue):
    """
    Update cloud service OTP value
    
    Parameters:
    cloudserviceotpvalue:	Cloud service OTP value
    
    Returns
    response    (dict)
    
    
    """
    
    vmanage.client.session.headers['Content-Type'] = "application/octet-stream"
    endpoint = f"dataservice/dca/cloudservices/otp"
    response = vmanage.apiCall("PUT", endpoint, cloudserviceotpvalue)
    return response
def listEntityOwnerInfo(vmanage):
    """
    List all entity ownership info
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/entityownership/list"
    response = vmanage.apiCall("GET", endpoint)
    return response
def entityOwnerInfo(vmanage):
    """
    Entity ownership info grouped by buckets
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/entityownership/tree"
    response = vmanage.apiCall("GET", endpoint)
    return response



def createCryptoIpsecIdentity(vmanage, rTlocAddr, rTlocColor, lTlocColor, deviceId):
    """
    Get Crypto IPSEC identity entry from device
    
    Parameters:
    rTlocAddr	 (string):	Remote TLOC address
	rTlocColor	 (string):	Remote tloc color
	lTlocColor	 (string):	Local tloc color
	deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ipsec/identity?rTlocAddr={rTlocAddr}&rTlocColor={rTlocColor}&lTlocColor={lTlocColor}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createIkeInboundList(vmanage, deviceId):
    """
    Get IPsec IKE inbound connection list from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ipsec/ike/inbound?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createIkeOutboundList(vmanage, deviceId):
    """
    Get IPsec IKE outbound connection list from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ipsec/ike/outbound?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createIkeSessions(vmanage, rTlocAddr, rTlocColor, deviceId):
    """
    Get IPsec IKE sessions from device
    
    Parameters:
    rTlocAddr	 (string):	Remote TLOC address
	rTlocColor	 (string):	Remote tloc color
	deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ipsec/ike/sessions?rTlocAddr={rTlocAddr}&rTlocColor={rTlocColor}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createCryptov1LocalSAList(vmanage, rTlocAddr, rTlocColor, deviceId):
    """
    Get Crypto IKEv1 SA entry from device
    
    Parameters:
    rTlocAddr	 (string):	Remote TLOC address
	rTlocColor	 (string):	Remote tloc color
	deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ipsec/ikev1?rTlocAddr={rTlocAddr}&rTlocColor={rTlocColor}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createCryptov2LocalSAList(vmanage, deviceId):
    """
    Get Crypto IKEv2 SA entry from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ipsec/ikev2?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createInBoundList(vmanage, rTlocAddr, rTlocColor, lTlocColor, deviceId):
    """
    Get IPsec inbound connection list from device (Real Time)
    
    Parameters:
    rTlocAddr	 (string):	Remote TLOC address
	rTlocColor	 (string):	Remote tloc color
	lTlocColor	 (string):	Local tloc color
	deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ipsec/inbound?rTlocAddr={rTlocAddr}&rTlocColor={rTlocColor}&lTlocColor={lTlocColor}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createLocalSAList(vmanage, deviceId):
    """
    Get IPsec local SA list from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ipsec/localsa?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createOutBoundList(vmanage, rTlocAddr, rTlocColor, deviceId):
    """
    Get IPsec outbound connection list from device (Real Time)
    
    Parameters:
    rTlocAddr	 (string):	Remote TLOC address
	rTlocColor	 (string):	Remote tloc color
	deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ipsec/outbound?rTlocAddr={rTlocAddr}&rTlocColor={rTlocColor}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createIPsecPWKInboundConnections(vmanage, rTlocAddr, rTlocColor, lTlocColor, deviceId):
    """
    Get IPSEC pairwise key inbound entry from device
    
    Parameters:
    rTlocAddr	 (string):	Remote TLOC address
	rTlocColor	 (string):	Remote tloc color
	lTlocColor	 (string):	Local tloc color
	deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ipsec/pwk/inbound?rTlocAddr={rTlocAddr}&rTlocColor={rTlocColor}&lTlocColor={lTlocColor}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createIPsecPWKLocalSA(vmanage, rTlocAddr, rTlocColor, lTlocColor, deviceId):
    """
    Get IPSEC pairwise key local SA  entry from device
    
    Parameters:
    rTlocAddr	 (string):	Remote TLOC address
	rTlocColor	 (string):	Remote tloc color
	lTlocColor	 (string):	Local tloc color
	deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ipsec/pwk/localsa?rTlocAddr={rTlocAddr}&rTlocColor={rTlocColor}&lTlocColor={lTlocColor}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createIPsecPWKOutboundConnections(vmanage, rTlocAddr, rTlocColor, lTlocColor, deviceId):
    """
    Get IPSEC pairwise key outbound entry from device
    
    Parameters:
    rTlocAddr	 (string):	Remote TLOC address
	rTlocColor	 (string):	Remote tloc color
	lTlocColor	 (string):	Local tloc color
	deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ipsec/pwk/outbound?rTlocAddr={rTlocAddr}&rTlocColor={rTlocColor}&lTlocColor={lTlocColor}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getCORStatus(vmanage):
    """
    Get Cloud On Ramp list
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor"
    response = vmanage.apiCall("GET", endpoint)
    return response

def createAndMap(vmanage, request):
    """
    Map Host to Transit VPC/VNet
    
    Parameters:
    request:	Map host to transit VPC request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor"
    response = vmanage.apiCall("POST", endpoint, request)
    return response

def raiseAlarmForAccount(vmanage, accountobject):
    """
    Raise alarm for account
    
    Parameters:
    accountobject:	Account object
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/account/alarm"
    response = vmanage.apiCall("POST", endpoint, accountobject)
    return response

def removeTransitVPC(vmanage, accountid, transitvpcid, cloudregion, cloudtype):
    """
    Delete transit VPC/VNet
    
    Parameters:
    accountid	 (string):	Account Id
	transitvpcid	 (string):	Cloud VPC Id
	cloudregion	 (string):	Cloud region
	cloudtype	 (string):	Cloud type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/accountid/{accountid}?transitvpcid={transitvpcid}&cloudregion={cloudregion}&cloudtype={cloudtype}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response

def acquireRP(vmanage, request):
    """
    Acquire IP from resource pool
    
    Parameters:
    request:	Add IP from resource pool request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/acquireResourcePool"
    response = vmanage.apiCall("POST", endpoint, request)
    return response

def getAmiList(vmanage, accountid, cloudregion, cloudtype):
    """
    Get AMI list
    
    Parameters:
    accountid	 (string):	Account Id
	cloudregion	 (string):	Cloud region
	cloudtype	 (string):	Cloud type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/ami?accountid={accountid}&cloudregion={cloudregion}&cloudtype={cloudtype}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getCloudList(vmanage):
    """
    Get cloud list
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/cloud"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getCloudAccounts(vmanage, cloudtype, cloudEnvironment):
    """
    Get cloud accounts
    
    Parameters:
    cloudtype	 (string):	Cloud type
	cloudEnvironment	 (string):	Cloud environment
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/cloud/account?cloudtype={cloudtype}&cloudEnvironment={cloudEnvironment}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def authCredAndUpdate(vmanage, credential):
    """
    Authenticate and update cloud account credentials
    
    Parameters:
    credential:	Cloud account credential
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/cloud/authenticate"
    response = vmanage.apiCall("PUT", endpoint, credential)
    return response

def authCORCredAndAdd(vmanage, credential):
    """
    Authenticate cloud account credentials
    
    Parameters:
    credential:	Cloud account credential
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/cloud/authenticate"
    response = vmanage.apiCall("POST", endpoint, credential)
    return response

def getCloudHostVpcAccountDetails(vmanage):
    """
    Get cloud host VPC account details
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/cloud/host/accountdetails"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getCloudMappedHostAccounts(vmanage, accountid, cloudtype):
    """
    Get cloud mapped accounts view
    
    Parameters:
    accountid	 (string):	Account Id
	cloudtype	 (string):	Cloud type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/cloud/mappedhostaccounts?accountid={accountid}&cloudtype={cloudtype}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def createRP(vmanage, request):
    """
    Add resource pool
    
    Parameters:
    request:	Add resource pool request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/createResourcePool"
    response = vmanage.apiCall("POST", endpoint, request)
    return response

def removeDeviceId(vmanage, accountid, transitvpcid, transitvpcname, cloudregion, cloudtype, devicePairId):
    """
    Remove device pair
    
    Parameters:
    accountid	 (string):	Account Id
	transitvpcid	 (string):	VPC Id
	transitvpcname	 (string):	VPC Name
	cloudregion	 (string):	Cloud region
	cloudtype	 (string):	Cloud type
	devicePairId	 (string):	Device pair Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/deleteDevicepair?accountid={accountid}&transitvpcid={transitvpcid}&transitvpcname={transitvpcname}&cloudregion={cloudregion}&cloudtype={cloudtype}&devicePairId={devicePairId}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response

def getCORDevices(vmanage):
    """
    Get available device list
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/device"
    response = vmanage.apiCall("GET", endpoint)
    return response

def addDevicePair(vmanage, request):
    """
    Add device pair
    
    Parameters:
    request:	Add device pair request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/devicepair"
    response = vmanage.apiCall("POST", endpoint, request)
    return response

def getHostVPCs(vmanage, transitVpcId, devicePairId):
    """
    Get host VPC details
    
    Parameters:
    transitVpcId	 (string):	Transit VPC Id
	devicePairId	 (string):	Device pair Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/devicepair/hostvpc?transitVpcId={transitVpcId}&devicePairId={devicePairId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getExternalId(vmanage):
    """
    Get the vManage external ID for AWS
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/externalId"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getTransitDevicePairAndHostList(vmanage, accountId, cloudRegion):
    """
    Get device and host details
    
    Parameters:
    accountId	 (string):	Account Id
	cloudRegion	 (string):	Cloud region
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/getTransitDevicePairAndHostList?accountId={accountId}&cloudRegion={cloudRegion}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getTransitVpcVpnList(vmanage, accountId):
    """
    Get transit VPN list
    
    Parameters:
    accountId	 (string):	Account Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/getTransitVpnList?accountId={accountId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getCloudHostVPCs(vmanage, accountid, cloudregion, cloudtype):
    """
    Get host VPC/VNet list
    
    Parameters:
    accountid	 (string):	Account Id
	cloudregion	 (string):	Cloud region
	cloudtype	 (string):	Cloud type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/hostvpc?accountid={accountid}&cloudregion={cloudregion}&cloudtype={cloudtype}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getTenantAndHostVpcList(vmanage, intent):
    """
    Get tenant and host VPC list
    
    Parameters:
    intent	 (string):	Intent
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/hostvpclist?intent={intent}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def updateHostVpcReachability(vmanage, updatevpcstatus):
    """
    Update host VPC reachability
    
    Parameters:
    updatevpcstatus:	Update VPC status
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/hostvpclist"
    response = vmanage.apiCall("PUT", endpoint, updatevpcstatus)
    return response

def getMappedVPCs(vmanage, accountid, cloudregion):
    """
    Get mapped VPC/VNet list
    
    Parameters:
    accountid	 (string):	Account Id
	cloudregion	 (string):	Cloud region
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/map?accountid={accountid}&cloudregion={cloudregion}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def mapVPCs(vmanage, host):
    """
    Map host to transit VPC/VNet
    
    Parameters:
    host:	Map host to VPC/VNet
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/map"
    response = vmanage.apiCall("POST", endpoint, host)
    return response

def unmapVPCs(vmanage, host):
    """
    Unmap host from transit VPC/VNet
    
    Parameters:
    host:	Unmap host to VPC/VNet
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/map"
    response = vmanage.apiCall("DELETE", endpoint, host)
    return response

def getPemKeyList(vmanage, accountid, cloudregion, cloudtype):
    """
    Get transit VPC PEM key list
    
    Parameters:
    accountid	 (string):	Account Id
	cloudregion	 (string):	Cloud region
	cloudtype	 (string):	Cloud type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/pem?accountid={accountid}&cloudregion={cloudregion}&cloudtype={cloudtype}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def scaleDown(vmanage, updatevpc):
    """
    Scale down cloud on ramp
    
    Parameters:
    updatevpc:	Update VPC
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/scale/down"
    response = vmanage.apiCall("POST", endpoint, updatevpc)
    return response

def scaleUp(vmanage, updatevpc):
    """
    Scale up cloud on ramp
    
    Parameters:
    updatevpc:	Update VPC
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/scale/up"
    response = vmanage.apiCall("POST", endpoint, updatevpc)
    return response

def updatestatus(vmanage, statusobject):
    """
    Update task status
    
    Parameters:
    statusobject:	Status object
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/status"
    response = vmanage.apiCall("POST", endpoint, statusobject)
    return response

def getTransitVPCs(vmanage, accountid, cloudregion, cloudtype):
    """
    Get transit VPC/VNet list
    
    Parameters:
    accountid	 (string):	Account Id
	cloudregion	 (string):	Cloud region
	cloudtype	 (string):	Cloud type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/transitvpc?accountid={accountid}&cloudregion={cloudregion}&cloudtype={cloudtype}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def updateTransitVPC(vmanage, vpc):
    """
    Update transit VPC/VNet
    
    Parameters:
    vpc:	VPC
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/transitvpc"
    response = vmanage.apiCall("PUT", endpoint, vpc)
    return response

def addTransitVPC(vmanage, vpc):
    """
    Create transit VPC/VNet
    
    Parameters:
    vpc:	VPC
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/transitvpc"
    response = vmanage.apiCall("POST", endpoint, vpc)
    return response

def updateTransitVpcAutoscaleProperties(vmanage, vpc):
    """
    Update transit VPC autoscale properties
    
    Parameters:
    vpc:	VPC
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/transitvpc/autoscale-properties"
    response = vmanage.apiCall("PUT", endpoint, vpc)
    return response

def getTransitVPCSupportedSize(vmanage, cloudtype, cloudEnvironment):
    """
    Get transit VPC supported size
    
    Parameters:
    cloudtype	 (string):	Cloud type
	cloudEnvironment	 (string):	Cloud environment
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cor/transitvpc/size?cloudtype={cloudtype}&cloudEnvironment={cloudEnvironment}"
    response = vmanage.apiCall("GET", endpoint)
    return response



import json

def getStatDataRawData(vmanage, query=None):
    """
    Get stats raw data
    
    Parameters:
    query	 (string):	Query dict
    
    Returns
    response    (dict)
    
    
    """
    if query:
        query_string = vmanage.builder.generateQuery(query)
        endpoint = f"dataservice/statistics/approute?query={query_string}"
    else:
        endpoint = f"dataservice/statistics/approute"
    response     = vmanage.apiCall("GET", endpoint)
    return response
def getStatsRawData(vmanage, query):
    """
    Get stats raw data
    
    Parameters:
    query:	Stats query dict
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/statistics/approute"
    response     = vmanage.apiCall("POST", endpoint, json.dumps(query))
    return response
def getAggregationDataByQuery(vmanage, query):
    """
    Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
    
    Parameters:
    query	 (string):	Query filter dict
    
    Returns
    response    (dict)
    
    
    """
    query_string = vmanage.builder.generateQuery(query)
    endpoint = f"dataservice/statistics/approute/aggregation?query={query_string}"
    response     = vmanage.apiCall("GET", endpoint)
    return response
def getPostAggregationDataByQuery(vmanage, query):
    """
    Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
    
    Parameters:
    query:	Stats query dict
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/statistics/approute/aggregation"
    response     = vmanage.apiCall("POST", endpoint, query)
    return response
def getPostAggregationAppDataByQuery(vmanage, query):
    """
    Get aggregated data based on input query and filters. The data can be filtered on time and other unique parameters based upon necessity and intended usage
    
    Parameters:
    query:	Stats query dict
    
    Returns
    response    (dict)
    
    
    """
    endpoint = f"dataservice/statistics/approute/app-agg/aggregation"
    response     = vmanage.apiCall("POST", endpoint, query)
    return response
def getStatDataRawDataAsCSV(vmanage, query):
    """
    Get raw data with optional query as CSV
    
    Parameters:
    query	 (string):	Query string
    
    Returns
    response    (dict)
    
    
    """
    query_string = vmanage.builder.generateQuery(query)
    endpoint = f"dataservice/statistics/approute/csv?query={query_string}"
    response     = vmanage.apiCall("GET", endpoint)
    return response
def getApprouteGridStat(vmanage, query):
    """
    Get statistics for top applications per tunnel in a grid table
    
    Parameters:
    query	 (string):	Query filter
    
    Returns
    response    (dict)
    
    
    """
    query_string = vmanage.builder.generateQuery(query)
    endpoint = f"dataservice/statistics/approute/device/tunnel/summary?query={query_string}"
    response     = vmanage.apiCall("GET", endpoint)
    return response
def getTunnel(vmanage, query):
    """
    Get statistics for top applications per tunnel in a grid table
    
    Parameters:
    query	 (string):	Query filter
    
    Returns
    response    (dict)
    
    
    """
    query_string = vmanage.builder.generateQuery(query)
    endpoint = f"dataservice/statistics/approute/device/tunnels?query={query_string}"
    response     = vmanage.apiCall("GET", endpoint)
    return response
def getCount(vmanage, query):
    """
    Get response count of a query
    
    Parameters:
    query	 (string):	Query
    
    Returns
    response    (dict)
    
    
    """
    query_string = vmanage.builder.generateQuery(query)
    endpoint = f"dataservice/statistics/approute/doccount?query={query_string}"
    response     = vmanage.apiCall("GET", endpoint)
    return response
def getCountPost(vmanage, query):
    """
    Get response count of a query
    
    Parameters:
    query:	Query
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/statistics/approute/doccount"
    response = vmanage.apiCall("POST", endpoint, query)
    return response
def getAggregationDataAppRoute(vmanage, queryfilter):
    """
    Get aggregation data and fec recovery rate
    
    Parameters:
    queryfilter:	Query filter
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/statistics/approute/fec/aggregation"
    response = vmanage.apiCall("POST", endpoint, queryfilter)
    return response
def getStatDataFields(vmanage):
    """
    Get fields and type
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/statistics/approute/fields"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStatBulkRawData(vmanage, query, scrollId, count):
    """
    Get stats raw data
    
    Parameters:
    query	 (string):	Query string
	scrollId	 (string):	ES scroll Id
	count	 (string):	Result size
    
    Returns
    response    (dict)
    
    
    """
    query_string = vmanage.builder.generateQuery(query)
    endpoint = f"dataservice/statistics/approute/page?query={query_string}&scrollId={scrollId}&count={count}"
    response     = vmanage.apiCall("GET", endpoint)
    return response
def getPostStatBulkRawData(vmanage, query, scrollId, count):
    """
    Get stats raw data
    
    Parameters:
    query:	Stats query string
	scrollId	 (string):	ES scroll Id
	count	 (string):	Result size
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/statistics/approute/page?scrollId={scrollId}&count={count}"
    response = vmanage.apiCall("POST", endpoint, query)
    return response
def getStatQueryFields(vmanage):
    """
    Get query fields
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/statistics/approute/query/fields"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getTunnelChart(vmanage, type, query):
    """
    Get tunnel top statistics in as chart
    
    Parameters:
    type	 (string):	Type
	query	 (string):	Query filter
    
    Returns
    response    (dict)
    
    
    """
    query_string = vmanage.builder.generateQuery(query)
    endpoint = f"dataservice/statistics/approute/tunnel/{type}/summary?query={query_string}"
    response     = vmanage.apiCall("GET", endpoint)
    return response
def getTunnelsSummary(vmanage, type, query, limit):
    """
    Get tunnel top statistics from device
    
    Parameters:
    type	 (string):	Type
	query	 (string):	Query filter
	limit	 (integer):	Query result size
    
    Returns
    response    (dict)
    
    
    """
    query_string = vmanage.builder.generateQuery(query)
    endpoint = f"dataservice/statistics/approute/tunnels/summary/{type}?query={query_string}&limit={limit}"
    response     = vmanage.apiCall("GET", endpoint)
    return response
def getTunnels(vmanage, type, query, limit):
    """
    Get tunnel top statistics from device
    
    Parameters:
    type	 (string):	Type
	query	 (string):	Query filter
	limit	 (integer):	Query result size
    
    Returns
    response    (dict)
    
    
    """
    query_string = vmanage.builder.generateQuery(query)
    endpoint = f"dataservice/statistics/approute/tunnels/{type}?query={query_string}&limit={limit}"
    response     = vmanage.apiCall("GET", endpoint)
    return response



def getCloudXStatus(vmanage):
    """
    Get CloudX feature list
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cloudx"
    response = vmanage.apiCall("GET", endpoint)
    return response

def addCloudxType(vmanage, cloudx, type):
    """
    Add cloudx gateway
    
    Parameters:
    cloudx:	Cloudx
	type	 (string):	Cloudx type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cloudx/addcloudx/{type}"
    response = vmanage.apiCall("POST", endpoint, cloudx)
    return response

def getAttachedClientList(vmanage):
    """
    Get attached client site list
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cloudx/attachedclient"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getAttachedDiaList(vmanage):
    """
    Get attached Dia site list
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cloudx/attacheddia"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getAttachedGwList(vmanage):
    """
    Get attached gateway list
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cloudx/attachedgateway"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getCloudXAvailableApps(vmanage):
    """
    Get CloudX available apps list
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cloudx/availableapps"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getSiteList(vmanage):
    """
    Get site list
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cloudx/clientlist"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getDiaList(vmanage):
    """
    Get Dia site list
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cloudx/dialist"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getGwList(vmanage):
    """
    Get gateway list
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cloudx/gatewaylist"
    response = vmanage.apiCall("GET", endpoint)
    return response

def addCloudxInterfaces(vmanage, cloudx):
    """
    Enable cloudx gateway
    
    Parameters:
    cloudx:	Cloudx
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cloudx/interfaces"
    response = vmanage.apiCall("POST", endpoint, cloudx)
    return response

def getApps(vmanage):
    """
    Get apps and vpns
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cloudx/manage/apps"
    response = vmanage.apiCall("GET", endpoint)
    return response

def editApps(vmanage, appVPN):
    """
    Edit apps and vpns
    
    Parameters:
    appVPN:	Cloudx apps and vpns
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cloudx/manage/apps"
    response = vmanage.apiCall("PUT", endpoint, appVPN)
    return response

def addApps(vmanage, appVPN):
    """
    Add apps and vpns
    
    Parameters:
    appVPN:	Cloudx apps and vpns
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cloudx/manage/apps"
    response = vmanage.apiCall("POST", endpoint, appVPN)
    return response

def sitePerApp(vmanage, appName, vpnId):
    """
    Get sites per application per vpn
    
    Parameters:
    appName	 (string):	App name
	vpnId	 (integer):	VPN Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/cloudx/status?appName={appName}&vpnId={vpnId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getInterface(vmanage, vpnId, ifname, mac, deviceId):
    """
    Get IPv6 Neighbors from device (Real Time)
    
    Parameters:
    vpnId	        (string):	VPN Id
	ifname	        (string):	Interface name
	mac	            (string):	Mac address
	deviceId	    (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ndv6?vpn-id={vpnId}&if-name={ifname}&mac={mac}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def createSDAConfig(vmanage, config, partnerId):
    """
    Create SDA enabled device
    
    Parameters:
    config:	Device SDA configuration
	partnerId	 (string):	Partner Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner/dnac/sda/config/{partnerId}"
    response = vmanage.apiCall("POST", endpoint, config)
    return response
def getSDAEnabledDevices(vmanage, partnerId):
    """
    Get SDA enabled devices
    
    Parameters:
    partnerId	 (string):	Partner Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner/dnac/sda/device/{partnerId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getDeviceDetails(vmanage, partnerId, uuid):
    """
    Get SDA enabled devices detail
    
    Parameters:
    partnerId	 (string):	Partner Id
	uuid	 (string):	Device uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner/dnac/sda/device/{partnerId}/{uuid}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createSDAConfigFromNetconf(vmanage, config, partnerId):
    """
    Create SDA enabled device from Netconf
    
    Parameters:
    config:	Device SDA configuration
	partnerId	 (string):	Partner Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner/dnac/sda/netconfconfig/{partnerId}"
    response = vmanage.apiCall("POST", endpoint, config)
    return response
def getSitesForPartner(vmanage, partnerId):
    """
    Get SDA enabled devices
    
    Parameters:
    partnerId	 (string):	Partner Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner/dnac/sda/site/{partnerId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getOverlayVPNList(vmanage):
    """
    Get Overlay VPN list
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner/dnac/sda/vpn"
    response = vmanage.apiCall("GET", endpoint)
    return response



def createSmuList(vmanage, deviceId):
    """
    Get software list from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/smu?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createSyncedSmuList(vmanage, deviceId):
    """
    Get software list from device synchronously
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/smu/synced?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSoftwareList(vmanage, deviceId):
    """
    Get software list from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/software?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSyncedSoftwareList(vmanage, deviceId):
    """
    Get software list from device synchronously
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/software/synced?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getSegments(vmanage):
    """
    Get network segments
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/segment"
    response = vmanage.apiCall("GET", endpoint)
    return response

def createSegment(vmanage, segmen):
    """
    Create network segment
    
    Parameters:
    segmen:	Network segment
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/segment"
    response = vmanage.apiCall("POST", endpoint, segmen)
    return response

def getSegment(vmanage, id):
    """
    Get network segment
    
    Parameters:
    id	 (string):	Segment Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/segment/{id}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def editSegment(vmanage, segmen, id):
    """
    Edit network segment
    
    Parameters:
    segmen:	Network segment
	id	 (string):	Segment Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/segment/{id}"
    response = vmanage.apiCall("PUT", endpoint, segmen)
    return response

def deleteSegment(vmanage, id):
    """
    Delete network segment
    
    Parameters:
    id	 (string):	Segment Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/segment/{id}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response



def getGlobalDropStats(vmanage, deviceId):
    """
    Get SD-WAN global drop statistics detail from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/sdwan-global-drop-statistics?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStats(vmanage, deviceId):
    """
    Get SD-WAN statistics detail from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/sdwan-stats?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def activate(vmanage):
    """
    Activate cluster to start working as primary
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/activate"
    response = vmanage.apiCall("POST", endpoint)
    return response

def getClusterInfo(vmanage):
    """
    Get disaster recovery cluster info
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/clusterInfo"
    response = vmanage.apiCall("GET", endpoint)
    return response

def restoreConfigDb(vmanage, payload):
    """
    Signal vManage to initiate configuration-db restore operation
    
    Parameters:
    payload:	Config-db meta payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/dbrestore"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response

def getConfigDBRestoreStatus(vmanage):
    """
    Config-db restore status
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/dbrestorestatus"
    response = vmanage.apiCall("GET", endpoint)
    return response

def deleteLocalDC(vmanage):
    """
    Delete local data center
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/deleteLocalDataCenter"
    response = vmanage.apiCall("POST", endpoint)
    return response

def deleteDC(vmanage):
    """
    Delete data center
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/deleteRemoteDataCenter"
    response = vmanage.apiCall("POST", endpoint)
    return response

def delete(vmanage):
    """
    Delete disaster recovery
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/deregister"
    response = vmanage.apiCall("POST", endpoint)
    return response

def getDetails(vmanage):
    """
    Get disaster recovery details
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/details"
    response = vmanage.apiCall("GET", endpoint)
    return response

def download(vmanage, token):
    """
    Downloading stats file
    
    Parameters:
    token	 (string):	Token
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/download/backup/{token}/db_bkp.tar.gz"
    response = vmanage.apiCall("GET", endpoint)
    return response

def downloadReplicationData(vmanage, token, fileName):
    """
    Download replication data
    
    Parameters:
    token	 (string):	Token
	fileName	 (string):	File name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/download/{token}/{fileName}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getDRStatus(vmanage):
    """
    Disaster recovery status
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/drstatus"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getHistory(vmanage):
    """
    Get disaster recovery switchover history
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/history"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getLocalHistory(vmanage):
    """
    Get disaster recovery local switchover history
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/localLatestHistory"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getLocalDCState(vmanage):
    """
    Get local data center details
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/localdc"
    response = vmanage.apiCall("GET", endpoint)
    return response

def pauseDR(vmanage):
    """
    Pause DR
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/pause"
    response = vmanage.apiCall("POST", endpoint)
    return response

def pauseLocalArbitrator(vmanage):
    """
    Pause DR for Local Arbitrator
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/pauseLocalArbitrator"
    response = vmanage.apiCall("POST", endpoint)
    return response

def pauseLocalDCForDR(vmanage):
    """
    Pause DR for Local datacenter
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/pauseLocalDC"
    response = vmanage.apiCall("POST", endpoint)
    return response

def pauseLocalDCReplication(vmanage):
    """
    Pause DR replication for Local datacenter
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/pauseLocalReplication"
    response = vmanage.apiCall("POST", endpoint)
    return response

def DRPauseReplication(vmanage):
    """
    Pause DR data replication
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/pausereplication"
    response = vmanage.apiCall("POST", endpoint)
    return response

def update(vmanage, request):
    """
    Update data centers for disaster recovery
    
    Parameters:
    request:	Datacenter registration request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/register"
    response = vmanage.apiCall("PUT", endpoint, request)
    return response

def register(vmanage, request):
    """
    Register data centers for disaster recovery
    
    Parameters:
    request:	Datacenter registration request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/register"
    response = vmanage.apiCall("POST", endpoint, request)
    return response

def getRemoteDCMembersState(vmanage):
    """
    Gets remote data center member state
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/remoteDcState"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getRemoteDataCenterState(vmanage):
    """
    Get remote data center details
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/remotedc"
    response = vmanage.apiCall("GET", endpoint)
    return response

def updateDRState(vmanage, dcReg):
    """
    Update complete disaster recovery information to remote data center
    
    Parameters:
    dcReg:	Datacenter registration
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/remotedc"
    response = vmanage.apiCall("POST", endpoint, dcReg)
    return response

def getRemoteDCVersion(vmanage):
    """
    Get remote data center vManage version
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/remotedc/swversion"
    response = vmanage.apiCall("GET", endpoint)
    return response

def DRReplicationRequest(vmanage, drrequest):
    """
    Replication Request message sent from primary
    
    Parameters:
    drrequest:	DR request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/requestimport"
    response = vmanage.apiCall("POST", endpoint, drrequest)
    return response

def restartDC(vmanage, dcReg):
    """
    Restart data center
    
    Parameters:
    dcReg:	Datacenter registration
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/restartDataCenter"
    response = vmanage.apiCall("POST", endpoint, dcReg)
    return response

def getDRLocalReplicationSchedule(vmanage):
    """
    Get disaster recovery local replication schedule
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/schedule"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getdrStatus(vmanage):
    """
    Get disaster recovery status
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/status"
    response = vmanage.apiCall("GET", endpoint)
    return response

def unpauseDR(vmanage):
    """
    Unpause DR
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/unpause"
    response = vmanage.apiCall("POST", endpoint)
    return response

def unpauseLocalArbitrator(vmanage):
    """
    Unpause DR for Local Arbitrator
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/unpauseLocalArbitrator"
    response = vmanage.apiCall("POST", endpoint)
    return response

def unpauseLocalDCForDR(vmanage):
    """
    Unpause DR for Local datacenter
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/unpauseLocalDC"
    response = vmanage.apiCall("POST", endpoint)
    return response

def unpauseLocalDCReplication(vmanage):
    """
    Unpause DR replication for local datacenter
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/unpauseLocalReplication"
    response = vmanage.apiCall("POST", endpoint)
    return response

def DRUnPauseReplication(vmanage):
    """
    Un-Pause DR data replication
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/unpausereplication"
    response = vmanage.apiCall("POST", endpoint)
    return response

def updateDrState(vmanage):
    """
    Update arbitrator with primary and secondary states cluster
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/updateDRConfigOnArbitrator"
    response = vmanage.apiCall("POST", endpoint)
    return response

def updateReplication(vmanage, replicationstatus):
    """
    Update DR replication status
    
    Parameters:
    replicationstatus:	Replication status
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/updateReplication"
    response = vmanage.apiCall("POST", endpoint, replicationstatus)
    return response

def getReachabilityInfo(vmanage, nodelist):
    """
    Validate a list of nodes
    
    Parameters:
    nodelist:	Node list
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/disasterrecovery/validateNodes"
    response = vmanage.apiCall("POST", endpoint, nodelist)
    return response



def createStats(vmanage, statsquery):
    """
    Get statistics data
    
    Parameters:
    statsquery:	Stats query
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/dca/analytics"
    response = vmanage.apiCall("PUT", endpoint, statsquery)
    return response
def getAllStatsDataDCA(vmanage, statssetting):
    """
    Get all statistics setting data
    
    Parameters:
    statssetting:	Stats setting
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/dca/analytics/all"
    response = vmanage.apiCall("POST", endpoint, statssetting)
    return response
def getAccessToken(vmanage):
    """
    Get DCA access token
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/dca/cloudservices/accesstoken"
    response = vmanage.apiCall("GET", endpoint)
    return response
def storeAccessToken(vmanage, dcaaccesstoken):
    """
    Set DCA access token
    
    Parameters:
    dcaaccesstoken:	DCA access token
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/dca/cloudservices/accesstoken"
    response = vmanage.apiCall("POST", endpoint, dcaaccesstoken)
    return response
def generateAlarm(vmanage, msg):
    """
    Generate DCA alarms
    
    Parameters:
    msg:	DCA alarm message
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/dca/cloudservices/alarm"
    response = vmanage.apiCall("POST", endpoint, msg)
    return response
def getIdToken(vmanage):
    """
    Get DCA Id token
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/dca/cloudservices/idtoken"
    response = vmanage.apiCall("GET", endpoint)
    return response
def storeIdToken(vmanage, token):
    """
    Set DCA Id token
    
    Parameters:
    token:	DCA Id token
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/dca/cloudservices/idtoken"
    response = vmanage.apiCall("POST", endpoint, token)
    return response
def getTelemetrySettings(vmanage):
    """
    Get DCA telemetry settings
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/dca/cloudservices/telemetry"
    response = vmanage.apiCall("GET", endpoint)
    return response
def generateDCADeviceStateData(vmanage, query, state_data_type):
    """
    Get device state data
    
    Parameters:
    query:	Query string
	state_data_type	 (string):	Device state data
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/dca/data/device/state/{state_data_type}"
    response = vmanage.apiCall("POST", endpoint, query)
    return response
def generateDCADeviceStatisticsData(vmanage, query, dataType):
    """
    Get device statistics data
    
    Parameters:
    query:	Query string
	dataType	 (string):	Device statistics data
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/dca/data/device/statistics/{dataType}"
    response = vmanage.apiCall("POST", endpoint, query)
    return response
def getDCATenantOwners(vmanage):
    """
    Get DCA tenant owners
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/dca/dcatenantowners"
    response = vmanage.apiCall("GET", endpoint)
    return response
def listAllDevicesDCA(vmanage, query):
    """
    Get all devices
    
    Parameters:
    query:	Query string
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/dca/device"
    response = vmanage.apiCall("POST", endpoint, query)
    return response
def getCrashLogs(vmanage, query):
    """
    Get crash log
    
    Parameters:
    query:	Query string
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/dca/device/crashlog/details"
    response = vmanage.apiCall("POST", endpoint, query)
    return response
def getCrashLogsSynced(vmanage, deviceId):
    """
    Get device crash log
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/dca/device/crashlog/synced?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getCloudServicesConfigurationDCA(vmanage):
    """
    Get DCA cloud service configuration
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/dca/settings/configuration/cloudservices/dca"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createDCAAnalyticsDataFile(vmanage, query, type):
    """
    Create analytics config data
    
    Parameters:
    query:	Query string
	type	 (string):	Data type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/dca/settings/configuration/{type}/dca"
    response = vmanage.apiCall("POST", endpoint, query)
    return response
def getStatsDBIndexStatus(vmanage, statssetting):
    """
    Get statistics setting status
    
    Parameters:
    statssetting:	Stats setting
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/dca/statistics/settings/status"
    response = vmanage.apiCall("POST", endpoint, statssetting)
    return response
def getDevicesDetailsDCA(vmanage, query):
    """
    Get device details
    
    Parameters:
    query:	Query string
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/dca/system/device"
    response = vmanage.apiCall("POST", endpoint, query)
    return response
def getDCAAttachedConfigToDevice(vmanage, query):
    """
    Get attached config to device
    
    Parameters:
    query:	Query string
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/dca/template/device/config/attachedconfig"
    response = vmanage.apiCall("POST", endpoint, query)
    return response
def getTemplatePolicyDefinitionsDCA(vmanage, query):
    """
    Get template policy definitions
    
    Parameters:
    query:	Query string
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/dca/template/policy/definition/approute"
    response = vmanage.apiCall("POST", endpoint, query)
    return response
def getVPNListsDCA(vmanage, query):
    """
    Get VPN details
    
    Parameters:
    query:	Query string
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/dca/template/policy/list/vpn"
    response = vmanage.apiCall("POST", endpoint, query)
    return response
def getVedgeTemplateListDCA(vmanage, query):
    """
    Get vEdge template list
    
    Parameters:
    query:	Query string
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/dca/template/policy/vedge"
    response = vmanage.apiCall("POST", endpoint, query)
    return response
def getVsmartTemplateListDCA(vmanage, query):
    """
    Get vSmart template list
    
    Parameters:
    query:	Query string
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/dca/template/policy/vsmart"
    response = vmanage.apiCall("POST", endpoint, query)
    return response



def getConnections(vmanage, deviceId):
    """
    Get cellular connection list from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/cellular/connection?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getHardwareList(vmanage, deviceId):
    """
    Get cellular hardware list from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/cellular/hardware?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getModemList(vmanage, policyId):
    """
    Get cellular modem list from device
    
    Parameters:
    policyId	 (string):	Policy IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/cellular/modem?policyId={policyId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getNetworkList(vmanage, deviceId):
    """
    Get cellular network list from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/cellular/network?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getProfileList(vmanage, deviceId):
    """
    Get cellular profile list from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/cellular/profiles?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getRadioList(vmanage, deviceId):
    """
    Get cellular radio list from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/cellular/radio?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSessionsList(vmanage, ifName, priDns, deviceId):
    """
    Get cellular session list from device
    
    Parameters:
    ifName	 (string):	Interface name
	priDns	 (string):	DNS primary IP
	deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/cellular/sessions?ifName={ifName}&priDns={priDns}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getCellularStatusList(vmanage, deviceId):
    """
    Get cellular status list from device
    
    Parameters:
    deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/cellular/status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def add(vmanage, policy):
    """
    Add internal policy from vmanage
    
    Parameters:
    policy:	    Internal Policy
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/mdp/policies/mdpconfig"
    response = vmanage.apiCall("PUT", endpoint, policy)
    return response



def createFull(vmanage):
    """
    Create full topology
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/topology"
    response = vmanage.apiCall("GET", endpoint)
    return response

def createDevice(vmanage, deviceId):
    """
    Create device topology
    
    Parameters:
    deviceId	 (array):	Device Id list
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/topology/device?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def createPhysical(vmanage, deviceId):
    """
    Create pysical topology
    
    Parameters:
    deviceId	 (array):	Device Id list
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/topology/physical?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



from py_viptela.api.config.builder.definition import acl
from py_viptela.api.config.builder.definition import acl6
from py_viptela.api.config.builder.definition import amp
from py_viptela.api.config.builder.definition import approute
from py_viptela.api.config.builder.definition import cflowd
from py_viptela.api.config.builder.definition import control
from py_viptela.api.config.builder.definition import data
from py_viptela.api.config.builder.definition import deviceacl
from py_viptela.api.config.builder.definition import deviceacl6
from py_viptela.api.config.builder.definition import dialpeer
from py_viptela.api.config.builder.definition import fxo
from py_viptela.api.config.builder.definition import fxs
from py_viptela.api.config.builder.definition import fxsdid
from py_viptela.api.config.builder.definition import hns
from py_viptela.api.config.builder.definition import ips
from py_viptela.api.config.builder.definition import isdn
from py_viptela.api.config.builder.definition import localdomain
from py_viptela.api.config.builder.definition import mesh
from py_viptela.api.config.builder.definition import qosmap
from py_viptela.api.config.builder.definition import rewriterule
from py_viptela.api.config.builder.definition import ruleset
from py_viptela.api.config.builder.definition import securitygroup
from py_viptela.api.config.builder.definition import ssl
from py_viptela.api.config.builder.definition import sslutd
from py_viptela.api.config.builder.definition import url
from py_viptela.api.config.builder.definition import vedgeroute
from py_viptela.api.config.builder.definition import vpn
from py_viptela.api.config.builder.definition import zbf


def getMasterTemplateList(vmanage, feature):
    """
    Generate template list
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    feature	 (string):	Feature
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device?feature={feature}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def createCLITemplate(vmanage, createtemplaterequest):
    """
    Create CLI template
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    createtemplaterequest:	Create template request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/cli"
    response = vmanage.apiCall("POST", endpoint, createtemplaterequest)
    return response

def createMasterTemplate(vmanage, request):
    """
    Create a device template from feature templates and sub templates
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    request:	Create template request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/feature"
    response = vmanage.apiCall("POST", endpoint, request)
    return response

def isMigrationRequired(vmanage):
    """
    Check if any device templates need migration
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/is_migration_required"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getTemplateForMigration(vmanage, hasAAA):
    """
    Generate a list of templates which require migration
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    hasAAA	 (boolean):	Return only those uses AAA
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/migration?hasAAA={hasAAA}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def migrateTemplates(vmanage, id, prefix, includeAll):
    """
    Migrate the device templates given the template Ids
    
    Parameters:
    id	 (array):	Template Id
	prefix	 (string):	Prefix
	includeAll	 (boolean):	Include all flag
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/migration?id={id}&prefix={prefix}&includeAll={includeAll}"
    response = vmanage.apiCall("POST", endpoint)
    return response

def migrationInfo(vmanage):
    """
    Returns the mapping between old and migrated templates
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/migration_info"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getMasterTemplateDefinition(vmanage, templateId):
    """
    Generate template by Id
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    templateId	 (string):	Template Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/object/{templateId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def changeTemplateResourceGroup(vmanage, templateId, resourceGroupName):
    """
    Change template resource group
    
    Parameters:
    templateId	 (string):	Template Id
	resourceGroupName	 (string):	Resource group name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/resource-group/{resourceGroupName}/{templateId}"
    response = vmanage.apiCall("POST", endpoint)
    return response

def getOutOfSyncTemplates(vmanage):
    """
    Get template sync status
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/syncstatus"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getOutOfSyncDevices(vmanage, templateId):
    """
    Get out of sync devices
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    templateId	 (string):	Template Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/syncstatus/{templateId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def editMasterTemplate(vmanage, template, templateId):
    """
    Edit template
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    template:	Template
	templateId	 (string):	Template Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/{templateId}"
    response = vmanage.apiCall("PUT", endpoint, template)
    return response

def deleteMasterTemplate(vmanage, templateId):
    """
    Delete template
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    templateId	 (string):	Template Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/device/{templateId}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response



def listLogFileDetails(vmanage):
    """
    Lists content of log file. This API accepts content type as text/plain. It is mandatory to provide response content type.  Any other content type would result in empty response.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    vmanage.client.session.headers['Content-Type'] = "text/plain"
    endpoint = f"dataservice/util/logfile/appserver"
    response = vmanage.apiCall("GET", endpoint)
    return response
def listVManageServerLogLastNLines(vmanage, lines):
    """
    List last N lines of log file. This API accepts content type as text/plain. It is mandatory to provide response content type.  Any other content type would result in empty response.
    
    Parameters:
    lines	 (integer):	Number of lines
    
    Returns
    response    (dict)
    
    
    """
    
    vmanage.client.session.headers['Content-Type'] = "text/plain"
    endpoint = f"dataservice/util/logfile/appserver/lastnlines?lines={lines}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def debugLog(vmanage, payload):
    """
    Test whether logging works
    
    Parameters:
    payload:	Request Payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/util/logging/debuglog"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response
def setLogLevel(vmanage, payload):
    """
    Set log level for logger
    
    Parameters:
    payload:	Request Payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/util/logging/level"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response
def listLoggers(vmanage):
    """
    List loggers
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/util/logging/loggers"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getUmbrellaDevReg(vmanage, deviceId):
    """
    Get Umbrella device registration from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/umbrella/device-registration?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUmbrellaDNSCrypt(vmanage, deviceId):
    """
    Get Umbrella DNScrypt information from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/umbrella/dnscrypt?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUmbrellaDpStats(vmanage, deviceId):
    """
    Get Umbrella dp-stats from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/umbrella/dp-stats?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUmbrellaOverview(vmanage, deviceId):
    """
    Get Umbrella overview from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/umbrella/overview?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getUmbrellaConfig(vmanage, deviceId):
    """
    Get Umbrella configuration from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/umbrella/umbrella-config?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getPolicies(vmanage, nmsId):
    """
    Retrieve MDP policies
    
    Parameters:
    nmsId:  NMS server ID
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/mdp/policies/{nmsId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def updatePolicyStatus(vmanage, policylist, nmsId):
    """
    update policy status
    
    Parameters:
    policylist:	policyList
	nmsId:  NMS server ID
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/mdp/policies/{nmsId}"
    response = vmanage.apiCall("PUT", endpoint, policylist)
    return response




def getACIDefinitions(vmanage):
    """
    Get ACI definitions
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner/aci/policy"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getDscpMappings(vmanage, partnerId):
    """
    Get DSCP policy
    
    Parameters:
    partnerId	 (string):	Partner Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner/aci/policy/dscpmapping/{partnerId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createDscpMappings(vmanage, acidefinition, partnerId):
    """
    Create an ACI definition entry
    
    Parameters:
    acidefinition:	ACI definition
	partnerId	 (string):	Partner Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner/aci/policy/dscpmapping/{partnerId}"
    response = vmanage.apiCall("POST", endpoint, acidefinition)
    return response
def deleteDscpMappings(vmanage, partnerId):
    """
    Delete DSCP mapping
    
    Parameters:
    partnerId	 (string):	Partner Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner/aci/policy/dscpmapping/{partnerId}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response
def getEvents(vmanage, partnerId, starttime, endtime):
    """
    Get ACI events
    
    Parameters:
    partnerId	 (string):	Partner Id
	starttime	 (integer):	Start time
	endtime	 (integer):	End time
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner/aci/policy/events/{partnerId}?starttime={starttime}&endtime={endtime}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getDataPrefixMappings(vmanage, partnerId):
    """
    Get prefix mapping
    
    Parameters:
    partnerId	 (string):	Partner Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner/aci/policy/prefixmapping/{partnerId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def setDataPrefixMappings(vmanage, prefixdefinition, partnerId):
    """
    Create data prefix mapping
    
    Parameters:
    prefixdefinition:	Prefix definition
	partnerId	 (string):	Partner Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner/aci/policy/prefixmapping/{partnerId}"
    response = vmanage.apiCall("POST", endpoint, prefixdefinition)
    return response
def getDataPrefixSequences(vmanage):
    """
    Get data prefix sequence
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/partner/aci/policy/sequences"
    response = vmanage.apiCall("GET", endpoint)
    return response



def deleteBkp(vmanage, fileName):
    """
    Delete all or a specific backup file stored in vManage
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    fileName	 (string):	File name
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenantbackup/delete?fileName={fileName}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response
def downloadBkpFile(vmanage, path):
    """
    Download a Backup File that is already stored in vManage
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
    path	 (string):	File path
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenantbackup/download/{path}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def exportBkp(vmanage):
    """
    Trigger a backup of configuration database and store it in vManage
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenantbackup/export"
    response = vmanage.apiCall("GET", endpoint)
    return response
def importBkp(vmanage):
    """
    Submit a previously backed up file and import the data and apply it to the configuraion database
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenantbackup/import"
    response = vmanage.apiCall("POST", endpoint)
    return response
def listBkp(vmanage):
    """
    List all backup files of a tenant stored in vManage
    NOTE: In a multitenant vManage system, this API is only available in the Provider view.
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/tenantbackup/list"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getHputStats(vmanage, deviceId):
    """
    Get Appqoe Hput Statistics from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/appqoe/appqoe-hput-stats?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getNatStats(vmanage, deviceId):
    """
    Get Appqoe Nat Statistics from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/appqoe/appqoe-nat-stats?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getRmResources(vmanage, deviceId):
    """
    Get Appqoe Resource Manager resources from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/appqoe/appqoe-rm-resource?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getRMStats(vmanage, deviceId):
    """
    Get Appqoe RM Statistics from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/appqoe/appqoe-rm-stats?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getServicesStatus(vmanage, deviceId):
    """
    Get Appqoe Services Status from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/appqoe/appqoe-services-status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSppiPipeStats(vmanage, deviceId):
    """
    Get Appqoe Sppi Pipe Stats from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/appqoe/appqoe-sppi-pipe-resource?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getSppiQueueStats(vmanage, deviceId):
    """
    Get Appqoe Sppi Queue Stats from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/appqoe/appqoe-sppi-queue-resource?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getClusterSummary(vmanage, deviceId):
    """
    Get Appqoe Cluster Summary from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/appqoe/cluster-summary?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getErrorRecent(vmanage, deviceId):
    """
    Get Appqoe error recent from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/appqoe/error-recent?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getFlowClosedError(vmanage, deviceId):
    """
    Get Appqoe flow closed error from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/appqoe/flow-closed-error?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getServiceControllers(vmanage, deviceId):
    """
    Get Appqoe service controllers from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/appqoe/service-controllers?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getStatus(vmanage, deviceId):
    """
    Get Appqoe status from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/appqoe/status?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getV6Data(vmanage, deviceId):
    """
    Get ipv6 data from device
    
    Parameters:
    Parameter Description
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/ipv6/nd6?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def createApplicationsDetailList(vmanage, vpnId, application, query):
    """
    Get list of cloudexpress applications from device (Real Time)
    
    Parameters:
    vpnId	 (string):	VPN Id
	application	 (string):	Application
	query	 (string):	Query
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/cloudx/application/detail?vpnId={vpnId}&application={application}&query={query}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createApplicationsList(vmanage, vpnId, application, query):
    """
    Get list of cloudexpress applications from device (Real Time)
    
    Parameters:
    vpnId	 (string):	VPN Id
	application	 (string):	Application
	query	 (string):	Query
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/cloudx/applications?vpnId={vpnId}&application={application}&query={query}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createGatewayExitsList(vmanage, vpnId, application, deviceId):
    """
    Get list of cloudexpress gateway exits from device (Real Time)
    
    Parameters:
    vpnId	 (string):	VPN Id
	application	 (string):	Application
	deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/cloudx/gatewayexits?vpnId={vpnId}&application={application}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createLbApplicationsList(vmanage, vpnId, application, query):
    """
    Get list of cloudexpress load balance applications from device (Real Time)
    
    Parameters:
    vpnId	 (string):	VPN Id
	application	 (string):	Application
	query	 (string):	Query
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/cloudx/loadbalance?vpnId={vpnId}&application={application}&query={query}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def createLocalExitsList(vmanage, vpnId, application, deviceId):
    """
    Get list of cloudexpress local exits from device (Real Time)
    
    Parameters:
    vpnId	 (string):	VPN Id
	application	 (string):	Application
	deviceId	 (string):	Device IP
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/cloudx/localexits?vpnId={vpnId}&application={application}&deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getFileContents(vmanage, uuid):
    """
    Get bootstrap file contents
    
    Parameters:
    uuid	 (string):	File uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/software/package/custom/file/{uuid}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def editConfigFile(vmanage, bootstrapfile, uuid):
    """
    Edit bootstrap file
    
    Parameters:
    bootstrapfile:	Bootstrap file
	uuid	 (string):	File uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/software/package/custom/file/{uuid}"
    response = vmanage.apiCall("PUT", endpoint, bootstrapfile)
    return response

def uploadImageFile(vmanage, type):
    """
    Upload virtual image/bootstrap file
    
    Parameters:
    type	 (string):	Upload file type
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/software/package/custom/uploads/{type}"
    response = vmanage.apiCall("POST", endpoint)
    return response

def createVnfPackage(vmanage, custompackage):
    """
    Create VNF custom package
    
    Parameters:
    custompackage:	Custom package
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/software/package/custom/vnfPackage"
    response = vmanage.apiCall("POST", endpoint, custompackage)
    return response



def generateChangePartitionInfo(vmanage, deviceId):
    """
    Get change partition information
    
    Parameters:
    deviceId	 (array):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/changepartition?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def processChangePartition(vmanage, payload):
    """
    Process change partition operation
    
    Parameters:
    payload:	Device change partition request payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/changepartition"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response

def generateDeactivateInfo(vmanage, deviceId):
    """
    Get deactivate partition information
    
    Parameters:
    deviceId	 (array):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/deactivate?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def processDeactivateSmu(vmanage, request):
    """
    Process deactivate operation for smu image
    
    Parameters:
    request:	Device smu image deactivate request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/deactivate"
    response = vmanage.apiCall("POST", endpoint, request)
    return response

def processDefaultPartition(vmanage, request):
    """
    Process marking default partition operation
    
    Parameters:
    request:	Marking default partition request
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/defaultpartition"
    response = vmanage.apiCall("POST", endpoint, request)
    return response

def createFilterVPNList(vmanage):
    """
    Get filter VPN list
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/filter/vpn"
    response = vmanage.apiCall("GET", endpoint)
    return response

def generateInstallInfo(vmanage, deviceId):
    """
    Generate install info
    
    Parameters:
    deviceId	 (array):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/install?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def processInstall(vmanage, payload):
    """
    Process an installation operation
    
    Parameters:
    payload:	Installation payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/install"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response

def generateDeviceList(vmanage, deviceType, groupId):
    """
    Get list of installed devices
    
    Parameters:
    Parameter Description
	Parameter Description
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/install/devices/{deviceType}?groupId={groupId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def generateDeviceActionList(vmanage):
    """
    Get device action list
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/list"
    response = vmanage.apiCall("GET", endpoint)
    return response

def processLxcActivate(vmanage, payload):
    """
    Process an activation operation
    
    Parameters:
    payload:	Activation request payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/lxcactivate"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response

def processLxcDelete(vmanage, payload):
    """
    Process a delete operation
    
    Parameters:
    payload:	Delete request payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/lxcdelete"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response

def processLxcInstall(vmanage, payload):
    """
    Process an installation operation
    
    Parameters:
    payload:	Installation request payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/lxcinstall"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response

def processLxcReload(vmanage, payload):
    """
    Process a reload operation
    
    Parameters:
    payload:	Reload request payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/lxcreload"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response

def processLxcReset(vmanage, payload):
    """
    Process a reset operation
    
    Parameters:
    payload:	Reset request payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/lxcreset"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response

def processLxcUpgrade(vmanage, payload):
    """
    Process an upgrade operation
    
    Parameters:
    payload:	Upgrade request payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/lxcupgrade"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response

def generateRebootInfo(vmanage, deviceId):
    """
    Get device reboot information
    
    Parameters:
    deviceId	 (array):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/reboot?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def processReboot(vmanage, payload):
    """
    Process a reboot operation
    
    Parameters:
    payload:	Device reboot request payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/reboot"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response

def generateRebootDeviceList(vmanage, deviceType, deviceId):
    """
    Get list of rebooted devices
    
    Parameters:
    Parameter Description
	Parameter Description
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/reboot/devices/{deviceType}?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def generateRediscoverInfo(vmanage):
    """
    Get rediscover operation information
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/rediscover"
    response = vmanage.apiCall("GET", endpoint)
    return response

def reDiscoverDevices(vmanage, payload):
    """
    Rediscover device
    
    Parameters:
    payload:	Rediscover device request payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/rediscover"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response

def reDiscoverAllDevice(vmanage, payload):
    """
    Rediscover all devices
    
    Parameters:
    payload:	Rediscover device request payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/rediscoverall"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response

def generateRemovePartitionInfo(vmanage, deviceId):
    """
    Get remove partition information
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/removepartition?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def processRemovePartition(vmanage, payload):
    """
    Process remove partition operation
    
    Parameters:
    payload:	Device remove partition request payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/removepartition"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response

def processDeleteAmpApiKey(vmanage, uuid):
    """
    Process amp api key deletion operation
    
    Parameters:
    uuid	 (string):	Uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/security/amp/apikey/{uuid}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response

def processAmpApiReKey(vmanage, payload):
    """
    Process amp api re-key operation
    
    Parameters:
    ampapire-keyrequestpayload:	AMP API re-key request payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/security/amp/rekey"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response

def testApiKey(vmanage, uuid):
    """
    Get API key from device
    
    Parameters:
    uuid	 (string):	Device uuid
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/security/apikey/{uuid}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def generateSecurityDevicesList(vmanage, policyType, groupId):
    """
    Get list of devices by security policy type
    
    Parameters:
    policyType	 (string):	Policy type
	Parameter Description
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/security/devices/{policyType}?groupId={groupId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def triggerPendingTasksMonitoring(vmanage):
    """
    Triggers global monitoring thread
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/startmonitor"
    response = vmanage.apiCall("GET", endpoint)
    return response

def testIoxConfig(vmanage, deviceIP):
    """
    testIoxConfig
    
    Parameters:
    Parameter Description
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/test/ioxconfig/{deviceIP}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def createUniqueVPNList(vmanage, deviceips):
    """
    Create unique VPN list
    
    Parameters:
    deviceips:	Device IPs
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/uniquevpnlist"
    response = vmanage.apiCall("POST", endpoint, deviceips)
    return response

def processVnfInstall(vmanage, payload):
    """
    Process an installation operation
    
    Parameters:
    payload:	Installation request payload
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/vnfinstall"
    response = vmanage.apiCall("POST", endpoint, payload)
    return response

def createVPNList(vmanage):
    """
    Create VPN list
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/vpn"
    response = vmanage.apiCall("GET", endpoint)
    return response

def getZTPUpgradeConfig(vmanage):
    """
    Get ZTP upgrade configuration
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/ztp/upgrade"
    response = vmanage.apiCall("GET", endpoint)
    return response

def processZTPUpgradeConfig(vmanage, ztpConfig):
    """
    Process ZTP upgrade configuration
    
    Parameters:
    ztpConfig:	ZTP upgrade config
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/ztp/upgrade"
    response = vmanage.apiCall("POST", endpoint, ztpConfig)
    return response

def getZTPUpgradeConfigSetting(vmanage):
    """
    Get ZTP upgrade configuration setting
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/ztp/upgrade/setting"
    response = vmanage.apiCall("GET", endpoint)
    return response

def processZTPUpgradeConfigSetting(vmanage, ztpSetting):
    """
    Process ZTP upgrade configuration setting
    
    Parameters:
    ztpSetting:	ZTP upgrade setting
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/action/ztp/upgrade/setting"
    response = vmanage.apiCall("POST", endpoint, ztpSetting)
    return response



def getAllKeys(vmanage):
    """
    Get keys from Umbrella
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/umbrella/getkeys"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getManagementKeys(vmanage):
    """
    Get management keys from Umbrella
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/umbrella/getkeys/management"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getNetworkKeys(vmanage):
    """
    Get network devices keys from Umbrella
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/umbrella/getkeys/networkdevices"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getReportingKeys(vmanage):
    """
    Get reporting keys from Umbrella
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/umbrella/getkeys/reporting"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getClient(vmanage, deviceId):
    """
    Get DHCP client from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/dhcp/client?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getInterface(vmanage, deviceId):
    """
    Get DHCP interfaces from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/dhcp/interface?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getServer(vmanage, deviceId):
    """
    Get DHCP server from device (Real Time)
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/dhcp/server?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response
def getV6Interface(vmanage, deviceId):
    """
    Get DHCPv6 interfaces from device
    
    Parameters:
    deviceId	 (string):	Device Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/device/dhcpv6/interface?deviceId={deviceId}"
    response = vmanage.apiCall("GET", endpoint)
    return response



def getVSmartPolicyTemplateList(vmanage):
    """
    Get all template vsmart policy list
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/vsmart"
    response = vmanage.apiCall("GET", endpoint)
    return response

def createVSmartTemplate(vmanage, templatepolicy):
    """
    Create template for given policy
    
    Parameters:
    templatepolicy:	Template policy
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/vsmart"
    response = vmanage.apiCall("POST", endpoint, templatepolicy)
    return response

def activatePolicyForCloudServices(vmanage, templatepolicy, policyId):
    """
    Activate vsmart policy for a given policy id
    
    Parameters:
    templatepolicy:	Template policy
	policyId	 (string):	Policy Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/vsmart/activate/central/{policyId}"
    response = vmanage.apiCall("POST", endpoint, templatepolicy)
    return response

def activatePolicy(vmanage, templatepolicy, policyId):
    """
    Activate vsmart policy for a given policy id
    
    Parameters:
    templatepolicy:	Template policy
	policyId	 (string):	Policy Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/vsmart/activate/{policyId}"
    response = vmanage.apiCall("POST", endpoint, templatepolicy)
    return response

def editTemplateWithoutLockChecks(vmanage, templatepolicy, policyId):
    """
    Edit template for given policy id to allow for multiple component edits
    
    Parameters:
    templatepolicy:	Template policy
	policyId	 (string):	Policy Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/vsmart/central/{policyId}"
    response = vmanage.apiCall("PUT", endpoint, templatepolicy)
    return response

def checkVSmartConnectivityStatus(vmanage):
    """
    Check VSmart Connectivity Status
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/vsmart/connectivity/status"
    response = vmanage.apiCall("GET", endpoint)
    return response

def deActivatePolicy(vmanage, policyId):
    """
    Deactivate vsmart policy for a given policy id
    
    Parameters:
    policyId	 (string):	Policy Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/vsmart/deactivate/{policyId}"
    response = vmanage.apiCall("POST", endpoint)
    return response

def getTemplateByPolicyId(vmanage, policyId):
    """
    Get template policy definition by policy id
    
    Parameters:
    policyId	 (string):	Policy Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/vsmart/definition/{policyId}"
    response = vmanage.apiCall("GET", endpoint)
    return response

def QosmosNbarMigrationWarning(vmanage):
    """
    Qosmos Nbar migration
    
    Parameters:
            
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/vsmart/qosmos_nbar_migration_warning"
    response = vmanage.apiCall("GET", endpoint)
    return response

def editVSmartTemplate(vmanage, templatepolicy, policyId):
    """
    Edit template for given policy id
    
    Parameters:
    templatepolicy:	Template policy
	policyId	 (string):	Policy Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/vsmart/{policyId}"
    response = vmanage.apiCall("PUT", endpoint, templatepolicy)
    return response

def deleteVSmartTemplate(vmanage, policyId):
    """
    Delete template for a given policy id
    
    Parameters:
    policyId	 (string):	Policy Id
    
    Returns
    response    (dict)
    
    
    """
    
    endpoint = f"dataservice/template/policy/vsmart/{policyId}"
    response = vmanage.apiCall("DELETE", endpoint)
    return response
